@@ -8,7 +8,7 @@ our $VERSION;
 use XSLoader ();
 
 BEGIN {
-    $VERSION = '0.01_01';
+    $VERSION = '0.01_90';
     XSLoader::load( __PACKAGE__, $VERSION );
 }
 
@@ -45,18 +45,25 @@ Net::mbedTLS - L<mbedTLS|https://tls.mbed.org/> in Perl
 
 =head1 DESCRIPTION
 
-L<OpenSSL|https://openssl.org> is great, and so is L<Net::SSLeay>,
-its Perl binding. Both are rather large, though.
+L<OpenSSL|https://openssl.org> is great but rather large.
 
 This distribution allows use of mbedTLS, a smaller, simpler TLS library,
 from Perl.
 
+=head1 BENEFITS & LIABILITIES
+
+This library, like mbedTLS itself, minimizes memory usage at
+the cost of performance. After a simple TLS handshake with this library
+Perl’s memory usage is about 6.5 MiB lower than when using
+L<IO::Socket::SSL> for the same. On the other hand, OpenSSL does the
+handshake (as of this writing) about 18 times faster.
+
 =head1 AVAILABLE FUNCTIONALITY
 
 For now this module largely just exposes the ability to do TLS. mbedTLS
-itself exposes a good deal more functionality (e.g., raw crypto,
-configurable ciphers); if you want that stuff, file a feature request.
-(Ideally send a patch.)
+itself exposes a good deal more functionality like raw crypto and
+configurable ciphers; if you want that stuff, file a feature request.
+(A patch with a test is highly desirable!)
 
 =head1 BUILDING/LINKING
 
@@ -66,7 +73,7 @@ This library can link to mbedTLS in several ways:
 
 =item * Dynamic, to system library (default): This assumes that
 mbedTLS is available from some system-default location (e.g.,
-F</usr/local>).
+F</usr>).
 
 =item * Dynamic, to a specific path: To do this set
 C<NET_MBEDTLS_MBEDTLS_BASE> in your environment to whatever directory
@@ -85,7 +92,11 @@ cost of always using the same library version.
 mbedTLS, alas, as of this writing does not support
 L<pkg-config|https://www.freedesktop.org/wiki/Software/pkg-config/>.
 (L<GitHub issue|https://github.com/ARMmbed/mbedtls/issues/228>) If that
-changes then dynamic linking will become more reliable.
+changes then dynamic linking may become more reliable.
+
+NB: mbedTLS B<MUST> be built with I<position-independent> code. If you’re
+building your own mbedTLS then you’ll need to configure that manually.
+GCC’s C<-fPIC> flag does this; see this distribution’s CI tests for an example.
 
 =cut
 
@@ -170,6 +181,21 @@ To abort the session without a warning, return -1.
 All other outcomes of this callback tell mbedTLS to continue the
 TLS handshake.
 
+=item * C<key_and_certs> - A reference to an array of key and certs.
+The array’s contents may be either:
+
+=over
+
+=item * 1 item: Concatenated PEM documents.
+
+=item * 2+ items: The key, then certificates. Any item may be in
+PEM or DER format, and any non-initial items (i.e., certificate items)
+may contain multiple certifictes.
+
+=back
+
+=back
+
 =cut
 
 sub create_server {
@@ -220,9 +246,25 @@ C<SSL_VERIFY_REQUIRED>
 
 #----------------------------------------------------------------------
 
-=head1 AUTHOR & COPYRIGHT
+=head1 SEE ALSO
 
-Copyright 2021 Gasper Software Consulting.
+L<Net::SSLeay>, an XS binding to OpenSSL, is Perl’s de facto standard TLS
+library.
+
+L<IO::Socket::SSL> wraps Net::SSLeay with logic to make TLS I<almost> as
+easy to use as plain TCP.
+
+#----------------------------------------------------------------------
+
+=head1 LICENSE & COPYRIGHT
+
+Copyright 2022 Gasper Software Consulting. All rights reserved.
+
+This library is licensed under the same terms as Perl itself.
+See L<perlartistic>.
+
+This library was originally a research project at
+L<cPanel, L.L.C.|https://cpanel.net>.
 
 =cut
 
