@@ -3,9 +3,6 @@ package Net::mbedTLS::Async;
 use strict;
 use warnings;
 
-use feature 'current_sub';
-
-use AnyEvent;
 use Promise::XS;
 use Scalar::Util;
 
@@ -47,21 +44,22 @@ sub shake_hands {
     my $weak_self = $self;
     Scalar::Util::weaken($weak_self);
 
-    sub {
-        my $sub = __SUB__;
-
+    my $shake_cr;
+    $shake_cr = sub {
         $d->reject($@) if !eval {
             if ( my $ok = $tls->shake_hands() ) {
                 $d->resolve();
             }
             else {
-                $weak_self->_handle_nonfatal_error($tls, $sub);
+                $weak_self->_handle_nonfatal_error($tls, $shake_cr);
             }
 
             1;
         };
     }->();
 
+    Scalar::Util::weaken($shake_cr);
+
     return $d->promise()->finally(
         sub { $self->_unset_event_listener() },
     );
@@ -74,26 +72,27 @@ Like C<read()> in L<Net::mbedTLS::Connection>.
 =cut
 
 sub read_any {
-    splice @_, 1, 0, 1;
+    splice @_, 1, 0, 1, 1;
 
     &_read;
 }
 
-=head2 promise($count) = I<OBJ>->read_all( $OUTPUT_BUFFER )
+=head2 promise() = I<OBJ>->read_all( $OUTPUT_BUFFER )
 
 Like C<read_any()> above but won’t resolve until the entire
-$OUTPUT_BUFFER has been written to.
+$OUTPUT_BUFFER has been written to. The returned promise
+resolves empty.
 
 =cut
 
 sub read_all {
-    splice @_, 1, 0, length $_[1];
+    splice @_, 1, 0, length $_[1], 0;
 
     &_read;
 }
 
 sub _read {
-    my ($self, $min) = @_;
+    my ($self, $min, $resolve_with_length_yn) = @_;
 
     my $tls = $self->[0];
 
@@ -107,8 +106,8 @@ sub _read {
         my $weak_self = $self;
         Scalar::Util::weaken($weak_self);
 
-        sub {
-            my $sub = __SUB__;
+        my $read_cr;
+        $read_cr = sub {
 
             my $ok = eval {
                 my $pos_sr = \$read_queue_ar->[0][_POS_IDX];
@@ -117,14 +116,14 @@ sub _read {
                     $$pos_sr += $got;
 
                     if ($$pos_sr >= $read_queue_ar->[0][_MIN_IDX]) {
-                        $read_queue_ar->[0][0]->resolve($$pos_sr);
+                        $read_queue_ar->[0][0]->resolve( $resolve_with_length_yn ? $$pos_sr : ());
                         shift @$read_queue_ar;
                     }
 
-                    __SUB__->() if @$read_queue_ar;
+                    $read_cr->() if @$read_queue_ar;
                 }
                 else {
-                    $weak_self->_handle_nonfatal_error($tls, $sub);
+                    $weak_self->_handle_nonfatal_error($tls, $read_cr);
                 }
 
                 1;
@@ -135,23 +134,40 @@ sub _read {
                 $_->[0]->reject($err) for splice @$read_queue_ar;
             }
         }->();
+
+        Scalar::Util::weaken($read_cr);
     }
 
     return $d->promise();
 }
 
+=head2 promise($count) = I<OBJ>->write_any( $OUTPUT_BUFFER )
+
+Writes as much of $OUTPUT_BUFFER as possible. The returned promise
+resolves with the number of bytes written. (It won’t resolve until
+I<at least> one byte is written.)
+
+=cut
+
 sub write_any {
-    push @_, 1;
+    push @_, 1, 1;
     &_write;
 }
 
+=head2 promise() = I<OBJ>->write_all( $OUTPUT_BUFFER )
+
+Like C<write_any()>, but the returned promise won’t resolve until
+all of $OUTPUT_BUFFER is sent. The returned promise resolves empty.
+
+=cut
+
 sub write_all {
-    push @_, length $_[1];
+    push @_, length $_[1], 0;
     &_write;
 }
 
 sub _write {
-    my ($self, $payload, $min) = @_;
+    my ($self, $payload, $min, $resolve_length_yn) = @_;
 
     my $d = Promise::XS::deferred();
 
@@ -164,8 +180,8 @@ sub _write {
         my $weak_self = $self;
         Scalar::Util::weaken($weak_self);
 
-        sub {
-            my $sub = __SUB__;
+        my $write_cr;
+        $write_cr = sub {
 
             my $ok = eval {
                 my $pos_sr = \$write_queue_ar->[0][_POS_IDX];
@@ -174,14 +190,14 @@ sub _write {
                     $$pos_sr += $sent;
 
                     if ($$pos_sr >= $write_queue_ar->[0][_MIN_IDX]) {
-                        $write_queue_ar->[0][0]->resolve($$pos_sr);
+                        $write_queue_ar->[0][0]->resolve( $resolve_length_yn ? $$pos_sr : () );
                         shift @$write_queue_ar;
                     }
 
-                    __SUB__->() if @$write_queue_ar;
+                    $write_cr->() if @$write_queue_ar;
                 }
                 else {
-                    $weak_self->_handle_nonfatal_error($tls, $sub);
+                    $weak_self->_handle_nonfatal_error($tls, $write_cr);
                 }
 
                 1;
@@ -192,6 +208,8 @@ sub _write {
                 $_->[0]->reject($err) for splice @$write_queue_ar;
             }
         }->();
+
+        Scalar::Util::weaken($write_cr);
     }
 }
 
